.. index.rst
.. 
.. Project: AutoArchive
.. License: GNU GPLv3
.. 
.. Copyright (C) 2003 - 2011 Róbert Čerňanský



.. User documentation master file.



#######################
AutoArchive User Manual
#######################

Contents
========

.. toctree::
   :maxdepth: 2

   general/description

   general/operations_explained

   general/arch_spec

   general/config_file

   general/examples

   general/general_information


.. toctree::
   :hidden:
   :glob:

   general/glossary
   man/*
   text/*



Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
* :ref:`glossary`
